RPReactionTimeActivity class

Reaction Time Test.

Inheritance
  • Object
  • Serializable
  • RPStep
  • RPActivityStep
  • RPReactionTimeActivity
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

RPReactionTimeActivity({required String identifier, bool includeInstructions = true, bool includeResults = true, int lengthOfTest = 30, int switchInterval = 4})
Contructor for creating a Reaction time Test.
RPReactionTimeActivity.fromJson(Map<String, dynamic> json)
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
footnote ↔ String?
Optional footer text to be displayed below the question. This can be used to provide additional information, such as copyright, or instructions. This text will be displayed in a smaller font size.
getter/setter pairinherited
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
A unique identifier of the Step. This identifier connects the step to its result (RPResult) object.
finalinherited
includeInstructions ↔ bool
Show the instruction before the test?
getter/setter pairinherited
includeResults ↔ bool
Show the results after the test?
getter/setter pairinherited
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
lengthOfTest ↔ int
The duration of the test. Default is 30 seconds.
getter/setter pair
nextButtonText ↔ String?
Text for the button that advances past this step.
getter/setter pairinherited
optional ↔ bool
Can this step be skipped? If so, the result for the step will be null.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepWidget → Widget
The widget (UI representation) of the step.
no setterinherited
switchInterval ↔ int
Max seconds until light switch-1. Writing 4 means at most 5 seconds. Default is 4.
getter/setter pair
text ↔ String?
The text of the Step. Different types of Steps are using the text text differently.
getter/setter pairinherited
timer ↔ Timer?
getter/setter pairinherited
title ↔ String
The title text. Different types of Steps are using the title text differently.
getter/setter pairinherited

Methods

calculateScore(dynamic result) → int
Calculates the score for this activity step.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stepBody(dynamic onResultChange(dynamic), RPActivityEventLogger eventLogger) → Widget
Initiates the UI component for an ActivityStep.
override
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited