RPStroopEffectActivity class

Stroop Effect Test.

Inheritance
  • Object
  • Serializable
  • RPStep
  • RPActivityStep
  • RPStroopEffectActivity
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

RPStroopEffectActivity({required String identifier, bool includeInstructions = true, bool includeResults = true, int lengthOfTest = 40, int displayTime = 1000, int delayTime = 750})
Contructor for creating a Stroop effect Test.
RPStroopEffectActivity.fromJson(Map<String, dynamic> json)
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
delayTime ↔ int
Amount of time between words in ms. Default is 750 ms.
getter/setter pair
displayTime ↔ int
Amount of time each word is displayed in milliseconds. Default is 1000 ms.
getter/setter pair
footnote ↔ String?
Optional footer text to be displayed below the question. This can be used to provide additional information, such as copyright, or instructions. This text will be displayed in a smaller font size.
getter/setter pairinherited
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
A unique identifier of the Step. This identifier connects the step to its result (RPResult) object.
finalinherited
includeInstructions ↔ bool
Show the instruction before the test?
getter/setter pairinherited
includeResults ↔ bool
Show the results after the test?
getter/setter pairinherited
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
lengthOfTest ↔ int
Test duration in seconds. Default is 40 seconds.
getter/setter pair
nextButtonText ↔ String?
Text for the button that advances past this step.
getter/setter pairinherited
optional ↔ bool
Can this step be skipped? If so, the result for the step will be null.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepWidget → Widget
The widget (UI representation) of the step.
no setterinherited
text ↔ String?
The text of the Step. Different types of Steps are using the text text differently.
getter/setter pairinherited
timer ↔ Timer?
getter/setter pairinherited
title ↔ String
The title text. Different types of Steps are using the title text differently.
getter/setter pairinherited

Methods

calculateScore(dynamic result) → int
Calculates the score for this activity step.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stepBody(dynamic onResultChange(dynamic), RPActivityEventLogger eventLogger) → Widget
Initiates the UI component for an ActivityStep.
override
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited