ContinuousVisualTrackingActivityBody class

The ContinuousVisualTrackingActivityBody class defines the UI for the continuous visual tracking task.

Inheritance

Constructors

ContinuousVisualTrackingActivityBody({Key? key, required RPUIContinuousVisualTrackingActivityBody topLevelWidget, required int numberOfTests, required int amountOfDots, required int amountOfTargets, required int dotSize, required Duration trackingSpeed})
the continuousVisualTrackingActivityBody constructor
const

Properties

amountOfDots → int
the number of dots to display
final
amountOfTargets → int
final
dotSize → int
the size of the dots to display
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
numberOfTests → int
the number of tests to run
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLevelWidget → RPUIContinuousVisualTrackingActivityBody
property to pass on the top level widget
final
trackingSpeed → Duration
the speed of the dots in milliseconds
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → ContinuousVisualTrackingActivityBodyState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited