ContinuousVisualTrackingActivityBodyState class

Inheritance

Constructors

ContinuousVisualTrackingActivityBodyState(RPUIContinuousVisualTrackingActivityBody sWidget, int numberOfTests, int amountOfDots, int amountOfTargets, int dotSize, Duration trackingSpeed)

Properties

amountOfDots → int
final
amountOfTargets → int
final
conCurrentNum ↔ int
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
distractors ↔ List<bool>
getter/setter pair
dots ↔ List<bool>
getter/setter pair
dotSize → int
final
finished ↔ bool
getter/setter pair
guess ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mistakes ↔ List<int>
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
numberOfTests → int
final
positions ↔ List<int>
getter/setter pair
rng ↔ Random
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds ↔ int
getter/setter pair
sWidget → RPUIContinuousVisualTrackingActivityBody
final
testTimer ↔ Timer?
Timer for the test
getter/setter pair
trackingSpeed → Duration
final
visualScoreList ↔ List<int>
getter/setter pair
waiting ↔ bool
getter/setter pair
widget → ContinuousVisualTrackingActivityBody
The current configuration.
no setterinherited
wrong ↔ int
getter/setter pair

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Build the main test phase
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant ContinuousVisualTrackingActivityBody oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
generatePositions() → List<int>
generate new positions for all dots
getDots(int amount, int targetAmount, BoxConstraints constraints, int avatarSize) → List<AnimatedPositioned>
initState() → void
Called when this object is inserted into the tree.
override
makeGuess() → void
make a guess and check if its correct
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
resetTest() → void
reset the test
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
shuffleDots() → void
find new positions for all dots
startTest() → void
start the test
startTimer() → void
start the timer
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited