DelayedRecallState class

Inheritance

Constructors

DelayedRecallState(RPUIDelayedRecallActivityBody sWidget, int numberOfTests)

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
finished ↔ bool
getter/setter pair
guess ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
numberOfTests → int
final
resultsList3 ↔ List<String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds ↔ int
getter/setter pair
sWidget → RPUIDelayedRecallActivityBody
final
time ↔ int
getter/setter pair
timer ↔ Timer?
getter/setter pair
timesTaken → List<int>
final
timesTaken2 → List<int>
final
waiting ↔ bool
getter/setter pair
widget → DelayedRecall
The current configuration.
no setterinherited
wordBuffer ↔ List<String>
getter/setter pair
words ↔ List<String>
getter/setter pair

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant DelayedRecall oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
initState() → void
Called when this object is inserted into the tree.
override
makeGuess() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
resetTest() → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
startTest() → void
startTimer() → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited