PathTracker class

Inheritance

Constructors

PathTracker(RPActivityEventLogger gestureController, List<Location> locations)

Properties

gestureController ↔ RPActivityEventLogger
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
index ↔ int
getter/setter pair
locations ↔ List<Location>
getter/setter pair
mistakeCount ↔ int
getter/setter pair
nextLocation ↔ Location
getter/setter pair
prevLocation ↔ Location
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ DateTime
getter/setter pair
taskStarted ↔ bool
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addNewPath(Offset pos) → void
deleteWrong() → void
dispose() → void
Discards any resources used by the object.
inherited
endCurrentPath() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited
updateCurrentPath(Offset newPos, void testConcluded(int result, int mistakes)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited